import {
  select,csv,scaleLinear,max,scaleBand,axisLeft,axisBottom
  ,format
} from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

//data handelling
const render = data =>{  
  //value access
  const xValue = d=>d.population;
  const yValue = d=>d.country;
  
  const margin ={top:50, right:30, bottom:50, left:120};
  const innerwidth = width - margin.right -margin.left;
  const innerheight = height - margin.top - margin.bottom;
        
  //data transformation
  const xScale = scaleLinear()
  .domain([0,max(data,xValue)])
  .range([0,innerwidth]);

  const yScale = scaleBand()
  .domain(data.map(yValue))
  .range([0,innerheight])
  .padding(0.1);
  
  
  //Margin
  const g = svg.append('g')
  	.attr('transform',`translate(${margin.left},${margin.top})`);
  
  //draw axis
  const xAxisTickFormat = number =>
  		format('.2s')(number)
  		.replace('G','B');
  
  const xAxis = axisBottom(xScale)
    .tickFormat(xAxisTickFormat)
  	.tickSize(-innerheight );
  
  g.append('g')
    .call(axisLeft(yScale))
  	.selectAll('.domain, .tick line')
  		.remove();
 
  const xAxisG = 
  g.append('g').call(xAxis)
  	.attr('transform',`translate(0,${innerheight})`)
  	
  xAxisG.selectAll('.domain')
  			.remove();
  
  //Axis lable
  xAxisG.append('text')
  			.attr('class','axis-label')
    		.attr('y',40)
  			.attr('x',innerwidth/2)
  			.text('population')
  			.attr('fill','black');
  
  //draw bars  
	g.selectAll('rect')
  .data(data)
  .enter().append('rect')
  	.attr('y',d=>yScale(yValue(d)))
  	.attr('width',d=>xScale(xValue(d)))
  	.attr('height',yScale.bandwidth());
  
  //add Chart title
  g.append('text')
    .attr('class','title')
  	.attr('y',-10)
  	.text('Top 10 most crowded countries')
  	.attr('x', innerwidth/3);
  
  
};

//get data and pass to data handelling
csv('data.csv').then(data=>{
	data.forEach(d => {
  	d.population = +d.population*1000;
  });
  render(data);
});

